
dlsia package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dlsia.core
   dlsia.test_data
   dlsia.viz_tools

Module contents
---------------

.. automodule:: dlsia
   :members:
   :undoc-members:
   :show-inheritance:
